@@ -140,7 +140,7 @@ qx.Class.define("callbackery.ui.plugin.Form", {
                     }
                     var required = control.getRequired();
                     if (required){
-                        if (data == null || data == '' ){
+                        if (data === null || data === '' ){
                             control.setValid(false);
                             return;
                         }
